@@ -3,7 +3,9 @@ import unittest
 from cligo.cli import CliApp
 from cligo.db.backends import SqliteDatabase
 
+
 PARENT_DIR = os.path.dirname(__file__)
+DB_NAME = 'temp_database.db'
 
 
 class CliGoTestCase(unittest.TestCase):
@@ -18,7 +20,7 @@ class CliGoTestCase(unittest.TestCase):
 
 class CligoDBTestCase(unittest.TestCase):
     def setUp(self):
-        database = SqliteDatabase(os.path.join(PARENT_DIR, 'temp_database.db'))
+        database = SqliteDatabase(os.path.join(PARENT_DIR, DB_NAME))
         CliApp.config(database)
         app = CliApp('Testapp')
 
@@ -26,4 +28,4 @@ class CligoDBTestCase(unittest.TestCase):
 
     def tearDown(self):
         CliApp.configuration.get('database').close()
-        os.remove(os.path.join(PARENT_DIR, 'temp_database.db'))
+        os.remove(os.path.join(PARENT_DIR, DB_NAME))
